@@ -27,6 +27,7 @@ import pango
 import threadpool
 import logging
 import geo
+from utils import HTMLManipulations
 logger = logging.getLogger('plugins')
 
 class HildonSearchPlace(object):
@@ -163,7 +164,7 @@ class HildonFieldnotes(object):
 
 
     def _on_upload_fieldnotes(self, some, thing):
-        self.core.on_upload_fieldnotes()
+        self.core.upload_fieldnotes()
 
     #emitted by core
     def _on_fieldnotes_changed(self, core):
@@ -489,7 +490,7 @@ class HildonSearchGeocaches(object):
             button.set_mode(False)
 
         def download_geocaches(widget):
-            self.core.update_coordinates(caches)
+            self.core.download_cache_details_list(caches)
 
 
 
@@ -553,18 +554,19 @@ class HildonAboutDialog(object):
         notebook.append_page(page, gtk.Label('About'))
 
         copyright = '''Copyright (C) in most parts 2012 Daniel Fett
-This program is free software: you can redistribute it and/or modify
-it under the terms of the GNU General Public License as published by
-the Free Software Foundation, either version 3 of the License, or
+
+This program is free software: you can redistribute it and/or modify \
+it under the terms of the GNU General Public License as published by \
+the Free Software Foundation, either version 3 of the License, or \
 (at your option) any later version.
 
-This program is distributed in the hope that it will be useful,
-but WITHOUT ANY WARRANTY; without even the implied warranty of
-MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+This program is distributed in the hope that it will be useful, \
+but WITHOUT ANY WARRANTY; without even the implied warranty of \
+MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the \
 GNU General Public License for more details.
 
-You should have received a copy of the GNU General Public License
-along with this program.  If not, see http://www.gnu.org/licenses/.
+You should have received a copy of the GNU General Public License \
+along with this program.  If not, see http://www.gnu.org/licenses/. \
 
 Author: Daniel Fett advancedcaching@fragcom.de'''
         additional = '''Neither the author nor the software is affiliated with or endorsed by any geocaching website.'''
@@ -580,7 +582,7 @@ Author: Daniel Fett advancedcaching@fragcom.de'''
         l = gtk.Label()
         l.set_line_wrap(True)
         l.set_alignment(0, 0)
-        l.set_size_request(self.window.size_request()[0] - 10, -1)
+        #l.set_size_request(self.window.size_request()[0] - 10, -1)
         l.set_markup(text)
         p = hildon.PannableArea()
         p.set_property('mov-mode', hildon.MOVEMENT_MODE_BOTH)
@@ -840,7 +842,7 @@ class HildonToolsDialog(object):
         def do_rot(widget):
             import cachedownloader
             try:
-                text = cachedownloader.CacheDownloader._rot13(source.get_buffer().get_text(source.get_buffer().get_start_iter(), source.get_buffer().get_end_iter()))
+                text = HTMLManipulations._rot13(source.get_buffer().get_text(source.get_buffer().get_start_iter(), source.get_buffer().get_end_iter()))
             except Exception:
                 text = ''
                 
